pub fn sync_threads()Expand description
Synchronization within a thread block. Disallow divergent control flow to ensure all threads in a block can reach the sync point to avoid deadlock.
pub fn sync_threads()Synchronization within a thread block. Disallow divergent control flow to ensure all threads in a block can reach the sync point to avoid deadlock.